@@ -10,9 +10,11 @@ from ipaddress import IPv4Address, IPv4Network
 from os import chdir, path
 from socketserver import ThreadingMixIn
 from threading import Thread
+from typing import List, Union
 
 import ifaddr  # type: ignore
 from RangeHTTPServer import RangeRequestHandler  # type: ignore
+from soco import SoCo  # type: ignore
 
 from soco_cli.utils import (
     error_report,
@@ -26,7 +28,7 @@ from soco_cli.utils import (
 PORT_START = 54000
 PORT_END = 54099
 
-SUPPORTED_TYPES = ["MP3", "M4A", "MP4", "FLAC", "OGG", "WMA", "WAV"]
+SUPPORTED_TYPES = ["MP3", "M4A", "MP4", "FLAC", "OGG", "WMA", "WAV", "AIFF"]
 
 
 class ThreadedHTTPServer(ThreadingMixIn, HTTPServer):
@@ -59,7 +61,7 @@ class MyHTTPHandler(RangeRequestHandler):
                 pass
             super().__init__(*args, **kwargs)
 
-    def do_GET(self):
+    def do_GET(self) -> None:
         logging.info("Get request received by HTTP server")
 
         # Only serve the specific file requested on the command line,
@@ -84,12 +86,14 @@ class MyHTTPHandler(RangeRequestHandler):
             # It's normal to hit some exceptions with Sonos
             logging.info("Exception ignored: {}".format(e))
 
-    def log_message(self, format, *args):
+    def log_message(self, format, *args) -> None:
         # Suppress HTTP logging
         return
 
 
-def http_server(server_ip, directory, filename, speaker_ips):
+def http_server(
+    server_ip: str, directory: str, filename: str, speaker_ips: List[str]
+) -> Union[ThreadedHTTPServer, None]:
     # Set the directory from which to serve files, in the handler
     # Set the specific filename and client IP that are authorised
     handler = functools.partial(
@@ -118,7 +122,7 @@ def http_server(server_ip, directory, filename, speaker_ips):
     return None
 
 
-def get_server_ip(speaker):
+def get_server_ip(speaker: SoCo) -> Union[str, None]:
     # Get a suitable IP address to use as a server address for Sonos
     # on this host
     adapters = ifaddr.get_adapters()
@@ -133,7 +137,7 @@ def get_server_ip(speaker):
     return None
 
 
-def wait_until_stopped(speaker, uri, end_on_pause):
+def wait_until_stopped(speaker: SoCo, uri: str, end_on_pause: bool):
 
     playing_states = ["PLAYING", "TRANSITIONING"]
     if not end_on_pause:
@@ -179,7 +183,7 @@ def wait_until_stopped(speaker, uri, end_on_pause):
     return
 
 
-def is_supported_type(filename):
+def is_supported_type(filename: str) -> bool:
     file_upper = filename.upper()
     for file_type in SUPPORTED_TYPES:
         if file_upper.endswith("." + file_type):
@@ -188,9 +192,7 @@ def is_supported_type(filename):
     return False
 
 
-def play_local_file(speaker, pathname, end_on_pause=False):
-    # speaker is a SoCo instance
-    # pathname is the local file to be played
+def play_local_file(speaker: SoCo, pathname: str, end_on_pause: bool = False) -> bool:
 
     if not path.exists(pathname):
         error_report("File '{}' not found".format(pathname))
