@@ -195,8 +195,11 @@ def main():
         exit(0)
 
     if len(args.parameters) == 0 and not args.interactive:
-        print("No parameters. Use 'sonos --help' for usage information", flush=True)
-        exit(0)
+        print(
+            "No parameters supplied. Use 'sonos --help' for usage information.",
+            flush=True,
+        )
+        exit(1)
 
     message = check_args(args)
     if message:
@@ -306,6 +309,8 @@ def main():
                             error_report(
                                 "Action 'loop' takes no parameters, or a number of iterations (> 0)"
                             )
+                            cumulative_exit_code += 1
+                            continue
                     loop_iterator -= 1
                     logging.info("Loop iterator countdown = {}".format(loop_iterator))
                     if loop_iterator <= 0:
@@ -333,6 +338,7 @@ def main():
                         error_report(
                             "Action 'loop_for' requires one parameter (duration >= 0)"
                         )
+                        cumulative_exit_code += 1
                     logging.info(
                         "Starting action 'loop_for' for duration {}s".format(
                             loop_duration
@@ -366,6 +372,7 @@ def main():
                         error_report(
                             "Action 'loop_until' requires one parameter (stop time)"
                         )
+                        cumulative_exit_code += 1
                     logging.info(
                         "Starting action 'loop_until' for duration {}s".format(
                             loop_duration
